use PDF::COS::Dict;
use PDF::Mask;
class PDF::Mask::Luminosity
    is PDF::COS::Dict
    does PDF::Mask {
        # /S /Luminosity
}
